==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/PolarLineSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { PolarLineSeriesBaseDescription } from "./PolarLineSeriesBaseDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var PolarLineSeriesDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarLineSeriesDescription, _super);
    function PolarLineSeriesDescription() {
        var _this = _super.call(this) || this;
        _this.e1 = null;
        return _this;
    }
    PolarLineSeriesDescription.prototype.get_type = function () {
        return "PolarLineSeries";
    };
    Object.defineProperty(PolarLineSeriesDescription.prototype, "unknownValuePlotting", {
        get: function () {
            return this.e1;
        },
        set: function (a) {
            this.e1 = a;
            this.e("UnknownValuePlotting");
        },
        enumerable: false,
        configurable: true
    });
    PolarLineSeriesDescription.$t = markType(PolarLineSeriesDescription, 'PolarLineSeriesDescription', PolarLineSeriesBaseDescription.$);
    return PolarLineSeriesDescription;
}(PolarLineSeriesBaseDescription));
export { PolarLineSeriesDescription };

==> igniteui-react-core-19.0.0.tgz: package/esm5/lib/PolarLineSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { PolarLineSeriesBaseDescription } from "./PolarLineSeriesBaseDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var PolarLineSeriesDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarLineSeriesDescription, _super);
    function PolarLineSeriesDescription() {
        var _this = _super.call(this) || this;
        _this.hb = null;
        return _this;
    }
    PolarLineSeriesDescription.prototype.get_type = function () {
        return "PolarLineSeries";
    };
    Object.defineProperty(PolarLineSeriesDescription.prototype, "unknownValuePlotting", {
        get: function () {
            return this.hb;
        },
        set: function (a) {
            this.hb = a;
            this.g("UnknownValuePlotting");
        },
        enumerable: false,
        configurable: true
    });
    PolarLineSeriesDescription.$t = markType(PolarLineSeriesDescription, 'PolarLineSeriesDescription', PolarLineSeriesBaseDescription.$);
    return PolarLineSeriesDescription;
}(PolarLineSeriesBaseDescription));
export { PolarLineSeriesDescription };
